@@ -23,7 +23,6 @@ extract_rhs <- function(model, ...) {
 #'   like subscripts are nested inside each list element. List elements with two
 #'   or more terms are interactions.
 #' @noRd
-#' @export
 #' @examples
 #' \dontrun{
 #' library(palmerpenguins)
@@ -75,7 +74,8 @@ extract_rhs <- function(model, ...) {
 #' # >   .. ..- attr(*, "names")= chr [1:2] "species" "flipper_length_mm"
 #' }
 #'
-extract_rhs.default <- function(model, index_factors) {
+extract_rhs.default <- function(model, index_factors, ...) {
+  check_dots(...)
   # Extract RHS from formula
   formula_rhs <- labels(terms(formula(model)))
 
@@ -112,8 +112,10 @@ extract_rhs.default <- function(model, index_factors) {
 }
 
 #' @noRd
-#' @export
-extract_rhs.lmerMod <- function(model, return_variances) {
+extract_rhs.lmerMod <- function(model, return_variances, ...) {
+
+  check_dots(...)
+    
   # Extract RHS from formula
   formula_rhs <- labels(terms(formula(model)))
 
@@ -223,7 +225,6 @@ extract_rhs.lmerMod <- function(model, return_variances) {
 }
 
 #' @noRd
-#' @export
 extract_rhs.glmerMod <- function(model, ...) {
   extract_rhs.lmerMod(model, ...)
 }
@@ -668,14 +669,12 @@ wrap_rhs <- function(model, tex, ...) {
   UseMethod("wrap_rhs", model)
 }
 
-#' @export
 #' @keywords internal
 #' @noRd
 wrap_rhs.default <- function(model, tex, ...) {
   return(tex)
 }
 
-#' @export
 #' @keywords internal
 #' @noRd
 wrap_rhs.glm <- function(model, tex, ...) {
@@ -688,7 +687,6 @@ wrap_rhs.glm <- function(model, tex, ...) {
   return(rhs)
 }
 
-#' @export
 #' @keywords internal
 #' @noRd
 wrap_rhs.polr <- function(model, tex, ...) {
@@ -701,7 +699,6 @@ wrap_rhs.polr <- function(model, tex, ...) {
   return(rhs)
 }
 
-#' @export
 #' @keywords internal
 #' @noRd
 wrap_rhs.clm <- function(model, tex, ...) {
